
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.011.
use strict;
use warnings;

use Module::Build 0.3601;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.4204"
  },
  "configure_requires" => {
    "Module::Build" => "0.4204"
  },
  "dist_abstract" => "Use time-stamp from Git instead of process start time.",
  "dist_author" => [
    "Kent Fredric <kentfredric\@gmail.com>"
  ],
  "dist_name" => "Dist-Zilla-Plugin-Git-NextRelease",
  "dist_version" => "0.002001",
  "license" => "perl",
  "module_name" => "Dist::Zilla::Plugin::Git::NextRelease",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "DateTime" => 0,
    "Dist::Zilla" => "5.000",
    "Dist::Zilla::Plugin::NextRelease" => 0,
    "Git::Wrapper::Plus" => "0.003100",
    "Moose" => 0,
    "String::Formatter" => "0.100680",
    "perl" => "5.008",
    "strict" => 0,
    "utf8" => 0,
    "warnings" => 0
  },
  "script_files" => [],
  "test_requires" => {
    "Cwd" => 0,
    "ExtUtils::MakeMaker" => 0,
    "File::Copy::Recursive" => 0,
    "File::Spec::Functions" => 0,
    "FindBin" => 0,
    "Git::Wrapper::Plus::Support" => 0,
    "Git::Wrapper::Plus::Tester" => 0,
    "List::Util" => 0,
    "Path::Tiny" => 0,
    "Test::DZil" => 0,
    "Test::Fatal" => 0,
    "Test::More" => "1.001002"
  }
);


my %fallback_build_requires = (
  "Cwd" => 0,
  "ExtUtils::MakeMaker" => 0,
  "File::Copy::Recursive" => 0,
  "File::Spec::Functions" => 0,
  "FindBin" => 0,
  "Git::Wrapper::Plus::Support" => 0,
  "Git::Wrapper::Plus::Tester" => 0,
  "List::Util" => 0,
  "Module::Build" => "0.4204",
  "Path::Tiny" => 0,
  "Test::DZil" => 0,
  "Test::Fatal" => 0,
  "Test::More" => "1.001002"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
