severity = 1
exclude = RequireTidyCode RequirePodSections ProhibitPostfixControls RequireRcsKeywords RequireExplicitPackage RequireExplicitInclusion PodMinimumVersion ProhibitEmptyCommas ProhibitFlagComments Editor::RequireEmacsFileVariables Documentation::RequirePODUseEncodingUTF8 CodeLayout::ProhibitHashBarewords CodeLayout::RequireASCII Miscellanea::ProhibitUselessNoCritic
include = Moose::ProhibitMultipleWiths Moose::ProhibitNewMethod Moose::RequireCleanNamespace Moose::RequireMakeImmutable
color = 1
verbose = 9

[BuiltinFunctions::ProhibitStringyEval]
allow_includes = 1

[CodeLayout::ProhibitTrailingWhitespace]

[Documentation::PodSpelling]
stop_words =

[Tics::ProhibitLongLines]
base_max = 130

[Subroutines::ProhibitUnusedPrivateSubroutines]
private_name_regex = _(?!build_)\w

[Subroutines::ProhibitCallsToUndeclaredSubs]
exempt_subs = String::Formatter::str_rf String::Formatter::_format_version

[TestingAndDebugging::RequireUseStrict]
equivalent_modules = Moose

[TestingAndDebugging::RequireUseWarnings]
equivalent_modules = Moose

